@@ -2,7 +2,7 @@
 **  Copyright (c) 2004-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The OpenDKIM Project.  All rights reserved.
 */
 
 #ifndef lint
@@ -77,7 +77,7 @@ static char ar_c_id[] = "@(#)$Id: ar.c,v 1.12 2010/10/04 21:20:47 cm-msk Exp $";
 #endif /* __RES && __RES >= 19940415 */
 
 /* ar includes */
-#include "ar.h"
+#include "async-resolv.h"
 #include "ar-socket.h"
 #include "ar-strl.h"
 #include "manual.h"
@@ -534,7 +534,7 @@ ar_elapsed(struct timeval *start, struct timeval *length)
 
 	tmp.tv_sec = start->tv_sec + length->tv_sec;
 	tmp.tv_usec = start->tv_usec + length->tv_usec;
-	if (tmp.tv_usec > 1000000)
+	if (tmp.tv_usec >= 1000000)
 	{
 		tmp.tv_usec -= 1000000;
 		tmp.tv_sec += 1;
@@ -1818,8 +1818,8 @@ ar_dispatcher(void *tp)
 			ar_socket_reset(lib->ar_dss);
 			ar_socket_add(lib->ar_dss, lib->ar_nsfd,
 			              AR_SOCKET_EVENT_WRITE);
-			status = ar_socket_wait(lib->ar_dss, 0);
-			if (status != 1)
+			if (ar_socket_check(lib->ar_dss, lib->ar_nsfd,
+			                    AR_SOCKET_EVENT_WRITE) != 1)
 				break;
 
 			pthread_mutex_lock(&q->q_lock);
@@ -2631,7 +2631,7 @@ ar_waitreply(AR_LIB lib, AR_QUERY query, size_t *len, struct timeval *timeout)
 		{
 			until.tv_sec = now.tv_sec + timeout->tv_sec;
 			until.tv_nsec = now.tv_usec + timeout->tv_usec;
-			if (until.tv_nsec > 1000000)
+			if (until.tv_nsec >= 1000000)
 			{
 				until.tv_sec += 1;
 				until.tv_nsec -= 1000000;
