@@ -4,26 +4,37 @@
 **
 **  Copyright (c) 2009, 2010 The OpenDKIM Project.  All rights reserved.
 **
-**  $Id: opendkim-crypto.c,v 1.8.12.1 2010/07/08 23:50:10 cm-msk Exp $
+**  $Id: opendkim-crypto.c,v 1.9.22.1 2010/10/27 21:43:09 cm-msk Exp $
 */
 
 #ifndef lint
-static char opendkim_crypto_c_id[] = "@(#)$Id: opendkim-crypto.c,v 1.8.12.1 2010/07/08 23:50:10 cm-msk Exp $";
+static char opendkim_crypto_c_id[] = "@(#)$Id: opendkim-crypto.c,v 1.9.22.1 2010/10/27 21:43:09 cm-msk Exp $";
 #endif /* !lint */
 
+#include "build-config.h"
+
 /* system includes */
 #include <sys/types.h>
-#include <stdbool.h>
+#ifdef HAVE_STDBOOL_H
+# include <stdbool.h>
+#endif /* HAVE_STDBOOL_H */
 #include <pthread.h>
 #include <stdlib.h>
+#include <stdio.h>
 #include <assert.h>
+#include <errno.h>
 
+#ifdef USE_GNUTLS
+/* libgnutls includes */
+# include <gnutls/gnutls.h>
+#else /* USE_GNUTLS */
 /* openssl includes */
-#include <openssl/crypto.h>
-#include <openssl/evp.h>
-#include <openssl/err.h>
-#include <openssl/ssl.h>
-#include <openssl/conf.h>
+# include <openssl/crypto.h>
+# include <openssl/evp.h>
+# include <openssl/err.h>
+# include <openssl/ssl.h>
+# include <openssl/conf.h>
+#endif /* USE_GNUTLS */
 
 /* opendkim includes */
 #include "opendkim-crypto.h"
@@ -31,6 +42,98 @@ static char opendkim_crypto_c_id[] = "@(#)$Id: opendkim-crypto.c,v 1.8.12.1 2010
 
 /* globals */
 static _Bool crypto_init_done = FALSE;
+
+#ifdef USE_GNUTLS
+
+static pthread_key_t logkey;
+
+/*
+**  DKIMF_CRYPTO_LOG -- log something from inside GnuTLS
+**
+**  Parameters:
+**  	sev -- log level
+**   	str -- string to log
+**
+**  Return value:
+**  	None.
+*/
+
+static void
+dkimf_crypto_log(int sev, const char *str)
+{
+	char *buf;
+
+	buf = pthread_getspecific(logkey);
+	if (buf == NULL)
+	{
+		buf = malloc(BUFRSZ);
+		pthread_setspecific(logkey, buf);
+	}
+
+	if (buf != NULL)
+		snprintf(buf, BUFRSZ, "%s", str);
+}
+
+/*
+**  DKIMF_CRYPTO_GETERROR -- return any logged error
+**
+**  Parameters:
+**  	None.
+**
+**  Return value:
+**  	Pointer to the most recently logged error, or NULL if none.
+*/
+
+const char *
+dkimf_crypto_geterror(void)
+{
+	return (const char *) pthread_getspecific(logkey);
+}
+
+/*
+**  DKIMF_CRYPTO_INIT -- set up GnuTLS dependencies
+**
+**  Parameters:
+**  	None.
+**
+**  Return value:
+**  	0 -- success
+**  	!0 -- an error code (a la errno)
+*/
+
+int
+dkimf_crypto_init(void)
+{
+	(void) gnutls_global_set_log_function(dkimf_crypto_log);
+	(void) gnutls_global_init();
+
+	(void) pthread_key_create(&logkey, free);
+
+	return 0;
+}
+
+/*
+**  DKIMF_CRYPTO_FREE -- tear down libGnuTLS dependencies
+**
+**  Parameters:
+**  	None.
+**
+**  Return value:
+**  	None.
+*/
+
+void
+dkimf_crypto_free(void)
+{
+	(void) gnutls_global_deinit();
+
+	(void) pthread_key_delete(logkey);
+
+	return;
+}
+
+#else /* USE_GNUTLS */
+
 static pthread_mutex_t id_lock;
 static pthread_key_t id_key;
 static unsigned int nmutexes = 0;
@@ -311,3 +414,5 @@ dkimf_crypto_free(void)
 		crypto_init_done = FALSE;
 	}
 }
+
+#endif /* USE_GNUTLS */
