@@ -26,6 +26,7 @@ static char opendkim_db_h_id[] = "@(#)$Id: opendkim-db.h,v 1.15 2010/09/16 04:47
 #define	DKIMF_DB_FLAG_USETLS	0x10
 #define	DKIMF_DB_FLAG_MAKELOCK	0x20
 #define	DKIMF_DB_FLAG_ASCIIONLY	0x40
+#define	DKIMF_DB_FLAG_NOFDLOCK	0x80
 
 #define	DKIMF_DB_TYPE_UNKNOWN	(-1)
 #define	DKIMF_DB_TYPE_FILE	0
@@ -36,6 +37,7 @@ static char opendkim_db_h_id[] = "@(#)$Id: opendkim-db.h,v 1.15 2010/09/16 04:47
 #define DKIMF_DB_TYPE_LDAP	5
 #define DKIMF_DB_TYPE_LUA	6
 #define DKIMF_DB_TYPE_MEMCACHE	7
+#define DKIMF_DB_TYPE_REPUTE	8
 
 #define	DKIMF_LDAP_PARAM_BINDUSER	0
 #define	DKIMF_LDAP_PARAM_BINDPW		1
@@ -73,15 +75,12 @@ typedef struct dkimf_db_data * DKIMF_DBDATA;
 #define	DKIMF_DB_DATA_OPTIONAL	0x02		/* data is optional */
 
 /* prototypes */
+extern int dkimf_db_chown __P((DKIMF_DB, uid_t uid));
 extern int dkimf_db_close __P((DKIMF_DB));
 extern int dkimf_db_delete __P((DKIMF_DB, void *, size_t));
-extern int dkimf_db_fd __P((DKIMF_DB));
 extern int dkimf_db_get __P((DKIMF_DB, void *, size_t,
                              DKIMF_DBDATA, unsigned int, _Bool *));
 extern int dkimf_db_mkarray __P((DKIMF_DB, char ***, const char **));
-#ifdef _FFR_OVERSIGN
-extern int dkimf_db_merge __P((DKIMF_DB, DKIMF_DB));
-#endif /* _FFR_OVERSIGN */
 extern int dkimf_db_open __P((DKIMF_DB *, char *, u_int flags,
                               pthread_mutex_t *, char **));
 extern int dkimf_db_put __P((DKIMF_DB, void *, size_t, void *, size_t));
